# Notes
- Directories `./shop/common` and `./root/common` are symbolic links which point to `./common`.

# Reminders
- This module is meant for highly portable applications and fancy source file management.
- This module is not aimed for stability and efficiency.
- Have fun.